
import sys
import lwsdk

__author__     = "Shu"
__date__       = "February 20 2020"
__version__    = "1.0"
__email__      = "www.m-bros.net/~shu"
__status__     = "Modeler"
__lwver__      = "2015"

class shu_Set_GENOMA_Null(lwsdk.ICommandSequence):
    def __init__(self, context):
        super(shu_Set_GENOMA_Null, self).__init__()

    def fast_poly_scan(self, poly_list, poly_id):
        poly_list.append(poly_id)
        return lwsdk.EDERR_NONE


    # LWCommandSequence -----------------------------------
    def process(self, mod_command):
        mesh_edit_op = mod_command.editBegin(0, 0, lwsdk.OPSEL_USER)
        if not mesh_edit_op:
            print >>sys.stderr, 'Failed to engage mesh edit operations!'
            return lwsdk.AFUNC_OK
            
        lwMF = lwsdk.LWMessageFuncs()
        polys = []

        edit_op_result = mesh_edit_op.fastPolyScan(mesh_edit_op.state, self.fast_poly_scan, (polys,), lwsdk.OPLYR_FG, 1)
        if len(polys) == 0:
            lwMF.info("Error", "No item selected.")
            mesh_edit_op.done(mesh_edit_op.state, edit_op_result, 0)
            return lwsdk.AFUNC_OK
        
        #No Genoma Check
        for poly in polys:
            genoma_info = mesh_edit_op.polyTag(mesh_edit_op.state, poly, lwsdk.LWID_('G','M','0','1'))
        
            if genoma_info == None:
                lwMF.info("Error", "No GENOMA Tag existing in this items.")
                mesh_edit_op.done(mesh_edit_op.state, edit_op_result, 0)
                return lwsdk.AFUNC_OK
        
        
        colorList = ['Black','Dark Blue','Dark Green','Dark Cyan','Dark Red','Purple','Brown','Gray','Blue','Green','Cyan','Red','Magenta','Orange','White']
        skColList  = ['Black','DkBlu','DkGrn','DkBlu','DkRed','Purple','Brown','Gray','Blue','Green','Blue','Red','Magen','Orang','White']
        skTypeList =['Bone','NULL','Joint']
        shTypeList =['Normal','Box','Ball','Pyramid','Diamond','Tetra','Ring','Grid','None']
        nulShpList =['Fsupport/genoma/shapes/ItemNull.lwo',
        'Fsupport/genoma/shapes/ItemNullBox.lwo',
        'Fsupport/genoma/shapes/ItemNullBall.lwo',
        'Fsupport/genoma/shapes/ItemNullPyramid.lwo',
        'Fsupport/genoma/shapes/ItemNullDiamond.lwo',
        'Fsupport/genoma/shapes/ItemNullTetra.lwo',
        'Fsupport/genoma/shapes/ItemNullRing.lwo',
        'Fsupport/genoma/shapes/ItemNullGrid.lwo',
        '']
        
        ui = lwsdk.LWPanels()
        title = 'Set GENOMA Null v%s' %__version__
        panel = ui.create(title)
        
        c0 = panel.popup_ctl('Genoma Color',colorList)
        c0.set_int(8)
        c1 = panel.popup_ctl('Skelgon Type',skTypeList)
        c1.set_int(0)
        c2 = panel.popup_ctl('Shape Type',shTypeList)
        c2.set_int(1)
        
        if panel.open(lwsdk.PANF_BLOCKING | lwsdk.PANF_CANCEL) == 0:
            ui.destroy(panel)
            mesh_edit_op.done(mesh_edit_op.state, edit_op_result, 0)
            return lwsdk.AFUNC_OK
        
        for poly in polys:
            skCol = mesh_edit_op.polyTag(mesh_edit_op.state, poly, lwsdk.LWID_('C','O','L','R'))
            genoma_info = mesh_edit_op.polyTag(mesh_edit_op.state, poly, lwsdk.LWID_('G','M','0','1'))
            gInfo = genoma_info.split("#")
            nullShape = mesh_edit_op.polyTag(mesh_edit_op.state, poly, lwsdk.LWID_('A','P','P','R'))

            # before status test view. 
            # print>> sys.stderr, "Befor:"+ nullShape

            cIndex0 = c0.get_int()
            cIndex1 = c1.get_int()
            cIndex2 = c2.get_int()
            gInfo[14] = str(cIndex0+1)
            gInfo[2] = str(cIndex1+1)
            gInfo[16] = str(cIndex2+1)
            
            # after status test view
            #print>> sys.stderr, gInfo
            #print>> sys.stderr, cIndex2
            #print>> sys.stderr, nulShpList
            
            
            genoma_info = "#".join(gInfo)
        
            mesh_edit_op.polTag(mesh_edit_op.state, poly, lwsdk.LWID_('C','O','L','R'),skColList[cIndex0])
            mesh_edit_op.polTag(mesh_edit_op.state, poly, lwsdk.LWID_('G','M','0','1'),genoma_info)
            
            #If NULL 
            if cIndex1 == 1:
                mesh_edit_op.polTag(mesh_edit_op.state, poly, lwsdk.LWID_('A','P','P','R'),str(nulShpList[cIndex2]))
            elif cIndex1 == 2:
                #joint
                mesh_edit_op.polTag(mesh_edit_op.state, poly, lwsdk.LWID_('A','P','P','R'),'Fsupport/genoma/shapes/ItemJoint.lwo')
            else:
                #default shape
                mesh_edit_op.polTag(mesh_edit_op.state, poly, lwsdk.LWID_('A','P','P','R'),'Fsupport/genoma/shapes/ItemBone.lwo')
            
        
        mesh_edit_op.done(mesh_edit_op.state, edit_op_result, 0)
        return lwsdk.AFUNC_OK


ServerTagInfo = [
                    ( "shu_Set_GENOMA_Null", lwsdk.SRVTAG_USERNAME | lwsdk.LANGID_USENGLISH ),
                    ( "shuGenomaNull", lwsdk.SRVTAG_BUTTONNAME | lwsdk.LANGID_USENGLISH ),
                    ( "Utilities/Python", lwsdk.SRVTAG_MENU | lwsdk.LANGID_USENGLISH )
                ]

ServerRecord = { lwsdk.CommandSequenceFactory("LW_PySetGenomaNull", shu_Set_GENOMA_Null) : ServerTagInfo }